@@ -60,7 +60,11 @@ def createCSVSchema(file, module, name, bases):
     """
     from userschema.schema import fromCSV
     schema = fromCSV(open(file), name, module.__name__, bases)
-    setattr(module, name, schema)
+    placeholder = getattr(module, name, None)
+    if placeholder is not None:
+        placeholder.__dict__.update(schema.__dict__)
+    else:
+        setattr(module, name, schema)
 
 def CSVSchemaDirective(_context, file, module, name, bases=()):
     # Directive handler for <userschema:csv> directive.
@@ -69,7 +73,7 @@ def CSVSchemaDirective(_context, file, module, name, bases=()):
     #        to use the synthesized interface in other ZCML directives.
     #        we will overwrite it later during 'createHTMLFormSchema' (in the
     #        "execute" phase).
-    dummy = InterfaceClass(name=name)
+    dummy = InterfaceClass(name=name, __module__=module.__name__)
     setattr(module, name, dummy)
 
     # Faux action, only for conflict resolution.
@@ -127,7 +131,11 @@ def createHTMLFormSchema(file, module, name, form, bases, encoding):
     from userschema.schema import fromHTMLForm
     schema = fromHTMLForm(open(file), name, form, module.__name__,
                           bases, encoding)
-    setattr(module, name, schema)
+    placeholder = getattr(module, name, None)
+    if placeholder is not None:
+        placeholder.__dict__.update(schema.__dict__)
+    else:
+        setattr(module, name, schema)
 
 def HTMLFormSchemaDirective(_context, file, module, name,
                             form=None, bases=(), encoding='UTF-8'):
@@ -137,7 +145,7 @@ def HTMLFormSchemaDirective(_context, file, module, name,
     #        to use the synthesized interface in other ZCML directives.
     #        we will overwrite it later during 'createHTMLFormSchema' (in the
     #        "execute" phase).
-    dummy = InterfaceClass(name=name)
+    dummy = InterfaceClass(name=name, __module__=module.__name__)
     setattr(module, name, dummy)
 
     # Faux action, only for conflict resolution.
@@ -187,7 +195,11 @@ def createXMLSchema(file, module, name, element_name, bases):
     from userschema.etree import fromXML
     schema = fromXML(open(file).read(), name, element_name, module.__name__,
                      bases)
-    setattr(module, name, schema)
+    placeholder = getattr(module, name, None)
+    if placeholder is not None:
+        placeholder.__dict__.update(schema.__dict__)
+    else:
+        setattr(module, name, schema)
 
 def XMLSchemaDirective(_context, file, module, name,
                        element_name=None, bases=()):
@@ -197,7 +209,7 @@ def XMLSchemaDirective(_context, file, module, name,
     #        to use the synthesized interface in other ZCML directives.
     #        we will overwrite it later during 'createXMLSchema' (in the
     #        "execute" phase).
-    dummy = InterfaceClass(name=name)
+    dummy = InterfaceClass(name=name, __module__=module.__name__)
     setattr(module, name, dummy)
 
     # Faux action, only for conflict resolution.
